@@ -4,7 +4,6 @@
 // http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
 // http://opensource.org/licenses/MIT>, at your option. This file may not be
 // copied, modified, or distributed except according to those terms.
-use cfg_if::cfg_if;
 use crate::thread_parker::{ThreadParker, ThreadParkerT, UnparkHandleT};
 use crate::util::UncheckedOptionExt;
 use crate::word_lock::WordLock;
@@ -16,43 +15,28 @@ use core::{
 use smallvec::SmallVec;
 use std::time::{Duration, Instant};
 
-cfg_if! {
+// Don't use Instant on wasm32-unknown-unknown, it just panics.
+cfg_if::cfg_if! {
     if #[cfg(all(
-        target_arch = "wasm32",
+        target_family = "wasm",
         target_os = "unknown",
         target_vendor = "unknown"
     ))] {
-        use core::ops::Add;
-
-        #[derive(Copy, Clone, PartialEq, Eq, PartialOrd, Ord, Debug, Hash)]
-        struct DummyInstant(Duration);
-
-        impl DummyInstant {
-            pub fn now() -> DummyInstant {
-                DummyInstant::zero()
-            }
-
-            const fn zero() -> DummyInstant {
-                DummyInstant(Duration::from_secs(0))
+        #[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
+        struct TimeoutInstant;
+        impl TimeoutInstant {
+            fn now() -> TimeoutInstant {
+                TimeoutInstant
             }
         }
-
-        impl Add<Duration> for DummyInstant {
-            type Output = DummyInstant;
-
-            fn add(self, _rhs: Duration) -> DummyInstant {
-                DummyInstant::zero()
+        impl core::ops::Add<Duration> for TimeoutInstant {
+            type Output = Self;
+            fn add(self, _rhs: Duration) -> Self::Output {
+                TimeoutInstant
             }
         }
-
-        // Use dummy implementation for `Instant` on `wasm32`. The reason for this is
-        // that `Instant::now()` will always panic because time is currently not implemented
-        // on wasm32-unknown-unknown.
-        // See https://github.com/rust-lang/rust/blob/master/src/libstd/sys/wasm/time.rs
-        type InstantType = DummyInstant;
     } else {
-        // Otherwise use `std::time::Instant`
-        type InstantType = Instant;
+        use std::time::Instant as TimeoutInstant;
     }
 }
 
@@ -87,7 +71,7 @@ impl HashTable {
         let new_size = (num_threads * LOAD_FACTOR).next_power_of_two();
         let hash_bits = 0usize.leading_zeros() - new_size.leading_zeros() - 1;
 
-        let now = InstantType::now();
+        let now = TimeoutInstant::now();
         let mut entries = Vec::with_capacity(new_size);
         for i in 0..new_size {
             // We must ensure the seed is not zero
@@ -117,7 +101,7 @@ struct Bucket {
 
 impl Bucket {
     #[inline]
-    pub fn new(timeout: InstantType, seed: u32) -> Self {
+    pub fn new(timeout: TimeoutInstant, seed: u32) -> Self {
         Self {
             mutex: WordLock::new(),
             queue_head: Cell::new(ptr::null()),
@@ -129,7 +113,7 @@ impl Bucket {
 
 struct FairTimeout {
     // Next time at which point be_fair should be set
-    timeout: InstantType,
+    timeout: TimeoutInstant,
 
     // the PRNG state for calculating the next timeout
     seed: u32,
@@ -137,14 +121,14 @@ struct FairTimeout {
 
 impl FairTimeout {
     #[inline]
-    fn new(timeout: InstantType, seed: u32) -> FairTimeout {
+    fn new(timeout: TimeoutInstant, seed: u32) -> FairTimeout {
         FairTimeout { timeout, seed }
     }
 
     // Determine whether we should force a fair unlock, and update the timeout
     #[inline]
     fn should_timeout(&mut self) -> bool {
-        let now = InstantType::now();
+        let now = TimeoutInstant::now();
         if now > self.timeout {
             // Time between 0 and 1ms.
             let nanos = self.gen_u32() % 1_000_000;
@@ -264,7 +248,7 @@ fn create_hashtable() -> &'static HashTable {
             // Free the table we created
             // SAFETY: `new_table` is created from `Box::into_raw` above and only freed here.
             unsafe {
-                Box::from_raw(new_table);
+                let _ = Box::from_raw(new_table);
             }
             old_table
         }
@@ -740,6 +724,10 @@ pub unsafe fn park(
 ///
 /// The `callback` function is called while the queue is locked and must not
 /// panic or call into any function in `parking_lot`.
+///
+/// The `parking_lot` functions are not re-entrant and calling this method
+/// from the context of an asynchronous signal handler may result in undefined
+/// behavior, including corruption of internal state and/or deadlocks.
 #[inline]
 pub unsafe fn unpark_one(
     key: usize,
@@ -817,6 +805,10 @@ pub unsafe fn unpark_one(
 /// You should only call this function with an address that you control, since
 /// you could otherwise interfere with the operation of other synchronization
 /// primitives.
+///
+/// The `parking_lot` functions are not re-entrant and calling this method
+/// from the context of an asynchronous signal handler may result in undefined
+/// behavior, including corruption of internal state and/or deadlocks.
 #[inline]
 pub unsafe fn unpark_all(key: usize, unpark_token: UnparkToken) -> usize {
     // Lock the bucket for the given key
@@ -1111,7 +1103,7 @@ pub mod deadlock {
     pub(super) use super::deadlock_impl::DeadlockData;
 
     /// Acquire a resource identified by key in the deadlock detector
-    /// Noop if deadlock_detection feature isn't enabled.
+    /// Noop if `deadlock_detection` feature isn't enabled.
     ///
     /// # Safety
     ///
@@ -1123,7 +1115,7 @@ pub mod deadlock {
     }
 
     /// Release a resource identified by key in the deadlock detector.
-    /// Noop if deadlock_detection feature isn't enabled.
+    /// Noop if `deadlock_detection` feature isn't enabled.
     ///
     /// # Panics
     ///
@@ -1165,17 +1157,17 @@ mod deadlock_impl {
     use std::collections::HashSet;
     use std::sync::atomic::Ordering;
     use std::sync::mpsc;
-    use thread_id;
+    use std::thread::ThreadId;
 
     /// Representation of a deadlocked thread
     pub struct DeadlockedThread {
-        thread_id: usize,
+        thread_id: ThreadId,
         backtrace: Backtrace,
     }
 
     impl DeadlockedThread {
         /// The system thread id
-        pub fn thread_id(&self) -> usize {
+        pub fn thread_id(&self) -> ThreadId {
             self.thread_id
         }
 
@@ -1196,7 +1188,7 @@ mod deadlock_impl {
         backtrace_sender: UnsafeCell<Option<mpsc::Sender<DeadlockedThread>>>,
 
         // System thread id
-        thread_id: usize,
+        thread_id: ThreadId,
     }
 
     impl DeadlockData {
@@ -1205,7 +1197,7 @@ mod deadlock_impl {
                 resources: UnsafeCell::new(Vec::new()),
                 deadlocked: Cell::new(false),
                 backtrace_sender: UnsafeCell::new(None),
-                thread_id: thread_id::get(),
+                thread_id: std::thread::current().id(),
             }
         }
     }
@@ -1484,7 +1476,7 @@ mod tests {
 
     test! {
         unpark_all_one_fast(
-            repeats: 10000, latches: 1, delay: 0, threads: 1, single_unparks: 0
+            repeats: 1000, latches: 1, delay: 0, threads: 1, single_unparks: 0
         );
         unpark_all_hundred_fast(
             repeats: 100, latches: 1, delay: 0, threads: 100, single_unparks: 0
